==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/projects/binding/src/lib/directives/ifPrinting.directive.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {ViewContainerRef, TemplateRef, Directive, Input, OnDestroy} from '@angular/core';
import {PrintersState} from '../state/PrintersState';
import {PrinterState} from '../state/PrinterState';
import {select} from '@angular-redux/store';
import {Observable, SubscriptionLike} from 'rxjs';

@Directive({
    selector: '[rsIfPrinting]'
})
export class IfPrintingDirective implements OnDestroy {
    private on: boolean;
    private active: PrinterState = undefined;
    @select('printers') printers$: Observable<PrintersState>;
    private activeSubscription: SubscriptionLike = null;

    constructor(private viewContainer: ViewContainerRef,
                private template: TemplateRef<any>) {
        this.activeSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (!this.active || p.active !== this.active.slug || this.active.printing !== p.printers[p.active].printing) {
                this.active = p.printers[p.active];
                this.update();
            }
        });
    }

    ngOnDestroy() {
        this.activeSubscription.unsubscribe();
    }

    update() {
        if (this.active && (this.active.printing === this.on)) {
            this.viewContainer.createEmbeddedView(this.template);
        } else {
            this.viewContainer.clear();
        }
    }

    @Input() set rsIfPrinting(condition) {
        this.on = condition;
        this.update();
    }

}

==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/projects/binding/src/lib/directives/ifPrinting.directive.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {ViewContainerRef, TemplateRef, Directive, Input, OnDestroy} from '@angular/core';
import {PrintersState} from '../state/PrintersState';
import {PrinterState} from '../state/PrinterState';
import {select} from '@angular-redux/store';
import {Observable, SubscriptionLike} from 'rxjs';

@Directive({
    selector: '[rsIfPrinting]'
})
export class IfPrintingDirective implements OnDestroy {
    private on: boolean;
    private active: PrinterState = undefined;
    @select('printers') printers$: Observable<PrintersState>;
    private activeSubscription: SubscriptionLike = null;

    constructor(private viewContainer: ViewContainerRef,
                private template: TemplateRef<any>) {
        this.activeSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (!this.active || p.active !== this.active.slug || this.active.printing !== p.printers[p.active].printing) {
                this.active = p.printers[p.active];
                this.update();
            }
        });
    }

    ngOnDestroy() {
        this.activeSubscription.unsubscribe();
    }

    update() {
        if (this.active && this.active.online === 1 && (this.active.printing === this.on)) {
            this.viewContainer.clear();
            this.viewContainer.createEmbeddedView(this.template);
        } else {
            this.viewContainer.clear();
        }
    }

    @Input() set rsIfPrinting(condition) {
        this.on = condition;
        this.update();
    }

}
